@@ -10,7 +10,7 @@ def add_whitelist(discord_id: int):
     return response.json()
 
 def del_whitelist(discord_id: int):
-    response = requests.delete(api_url + f"premium_add?discord_id={discord_id}&api_key={apikey}")
+    response = requests.delete(api_url + f"premium?discord_id={discord_id}&api_key={apikey}")
     return response.json()
 
 def reset_whitelist(discord_id: int):
@@ -18,5 +18,5 @@ def reset_whitelist(discord_id: int):
     return response.json()
 
 def whitelist(discord_id: int):
-    response = requests.get(api_url + f"premium_add?discord_id={discord_id}&api_key={apikey}")
+    response = requests.get(api_url + f"premium?discord_id={discord_id}&api_key={apikey}")
     return response.json()
\ No newline at end of file
